@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.0306';
+our $VERSION = '0.0307';
 
 use List::Util qw( min );
 
@@ -21,13 +21,13 @@ our @EXPORT = qw(
     cyclic_permutation
 );
 
-my $SIZE  = 3;  # Default chord size
-my $SCALE = 12; # Default number of scale notes
+use constant SIZE  => 3;  # Default chord size
+use constant SCALE => 12; # Default number of scale notes
 
 
 sub barycenter {
-    my $size  = shift || $SIZE;  # Default to a triad
-    my $scale = shift || $SCALE; # Default to the common scale notes
+    my $size  = shift || SIZE;  # Default to a triad
+    my $scale = shift || SCALE; # Default to the common scale notes
     return ($scale / $size) x $size;
 }
 
@@ -97,7 +97,7 @@ Music::Interval::Barycentric - Compute barycentric musical interval space
 
 =head1 VERSION
 
-version 0.0306
+version 0.0307
 
 =head1 SYNOPSIS
 
@@ -105,16 +105,16 @@ version 0.0306
 
  my @chords = ([3,4,5], [0,4,7]); # Given in "pitch-class notation"
 
- my @center = barycenter(scalar @{ $chords[0] });
- # [4,4,4]
-
  my $dist = distance(@chords);
  $dist = orbit_distance(@chords);
  $dist = forte_distance(@chords);
  my $even = evenness_index($chords[0]);
 
- my $cycles = cyclic_permutation(2,4,6);
- # [[2,4,6], [6,2,4], [4,6,2]]
+ my $cycles = cyclic_permutation($chords[0]);
+ # [[3,4,5], [5,3,4], [4,5,3]]
+
+ my @center = barycenter(scalar @{ $chords[0] });
+ # [4,4,4]
 
 =head1 DESCRIPTION
 
@@ -183,7 +183,7 @@ Return a chord distance from the barycenter.
 
 =head1 SEE ALSO
 
-The F<eg/*> programs in this distribution.
+The F<t/01-functions.t> and F<eg/*> programs in this distribution.
 
 L<http://www.amazon.com/Geometry-Musical-Chords-Interval-Representation/dp/145022797X>
 "A New Geometry of Musical Chords in Interval Representation: Dissonance, Enrichment, Degeneracy and Complementation"
